@@ -32,7 +32,7 @@ ALARM_DEF_123_FIELDS = {'actions_enabled': False,
                         'alarm_actions': u'29387234,77778687',
                         'description': None,
                         'expression': u'AVG(hpcs.compute{flavor_id=777, '
-                        'image_id=888, metric_name=cpu, device=1}) > 10',
+                        'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                         'id': u'123',
                         'match_by': u'flavor_id,image_id',
                         'name': u'90% CPU',
@@ -134,7 +134,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                              'name': '90% CPU',
                              'severity': 'LOW',
                              'expression': 'AVG(hpcs.compute{flavor_id=777,'
-                             ' image_id=888, metric_name=cpu, device=1}) > 10',
+                             ' image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                              'match_by': 'flavor_id,image_id',
                              'actions_enabled': False,
                              'created_at': datetime.datetime.now(),
@@ -161,7 +161,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                               'threshold': 10,
                               'period': 60,
                               'periods': 1,
-                              'is_deterministic': False,
+                              'is_deterministic': True,
                               'created_at': datetime.datetime.now(),
                               'updated_at': datetime.datetime.now()},
                              {'id': '222',
@@ -286,6 +286,26 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
             count_sadd = conn.execute(query_sadd, id=count_sad[0][0]).fetchone()
             self.assertEqual(count_sadd[0], 3)
 
+    def test_should_try_to_create_with_wrong_alarm_action(self):
+        expression = ('AVG(hpcs.compute{flavor_id=777, image_id=888,'
+                      ' metric_name=cpu}) > 10')
+        description = ''
+        match_by = ['flavor_id', 'image_id']
+        sub_expr_list = alarm_expr_parser.AlarmExprParser(expression).sub_expr_list
+        alarm_actions = ['66666666']
+        args = ('555',
+                '90% CPU',
+                expression,
+                sub_expr_list,
+                description,
+                'LOW',
+                match_by,
+                alarm_actions,
+                None,
+                None)
+        self.assertRaises(exceptions.InvalidUpdateException,
+                          self.repo.create_alarm_definition, *args)
+
     def test_should_update(self):
         expression = ''.join(['AVG(hpcs.compute{flavor_id=777, image_id=888,',
                               ' metric_name=mem}) > 20 and',
@@ -360,7 +380,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'alarm_actions': '29387234,77778687',
                      'description': None,
                      'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                     'image_id=888, metric_name=cpu, device=1}) > 10',
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                      'id': '123',
                      'match_by': 'flavor_id,image_id',
                      'name': '90% CPU',
@@ -388,7 +408,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'alarm_actions': '29387234,77778687',
                      'description': None,
                      'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                     'image_id=888, metric_name=cpu, device=1}) > 10',
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                      'id': '123',
                      'match_by': 'flavor_id,image_id',
                      'name': '90% CPU',
@@ -484,7 +504,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                     'alarm_actions': '29387234,77778687',
                     'description': None,
                     'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                    'image_id=888, metric_name=cpu, device=1}) > 10',
+                    'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                     'id': '123',
                     'match_by': 'flavor_id,image_id',
                     'name': '90% CPU',
@@ -511,7 +531,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'operator': 'GT',
                      'period': 60,
                      'periods': 1,
-                     'is_deterministic': False,
+                     'is_deterministic': True,
                      'threshold': 10.0}]
 
         self.assertEqual(len(sub_alarms), len(expected))
@@ -556,6 +576,17 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
         sub_alarms = self.repo.get_sub_alarm_definitions('asdfasdf')
         self.assertEqual(sub_alarms, [])
 
+    def test_try_update_alarm_that_does_not_exist(self):
+        args = ('koala', '999',
+                None, None,
+                None, True,
+                None, None,
+                None, None,
+                None, None,
+                True)
+        self.assertRaises(exceptions.DoesNotExistException,
+                          self.repo.update_or_patch_alarm_definition, *args)
+
     def test_exists(self):
         alarmDef1 = self.repo.get_alarm_definitions(tenant_id='bob',
                                                     name='90% CPU')
@@ -563,7 +594,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                     'alarm_actions': '29387234,77778687',
                     'description': None,
                     'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                    'image_id=888, metric_name=cpu, device=1}) > 10',
+                    'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                     'id': '123',
                     'match_by': 'flavor_id,image_id',
                     'name': '90% CPU',
@@ -583,7 +614,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'alarm_actions': '29387234,77778687',
                      'description': None,
                      'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                     'image_id=888, metric_name=cpu, device=1}) > 10',
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                      'id': '123',
                      'match_by': 'flavor_id,image_id',
                      'name': '90% CPU',
@@ -646,7 +677,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'alarm_actions': '29387234,77778687',
                      'description': None,
                      'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                     'image_id=888, metric_name=cpu, device=1}) > 10',
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                      'id': '123',
                      'match_by': 'flavor_id,image_id',
                      'name': '90% CPU',
@@ -676,7 +707,7 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                      'alarm_actions': '29387234,77778687',
                      'description': None,
                      'expression': 'AVG(hpcs.compute{flavor_id=777, '
-                     'image_id=888, metric_name=cpu, device=1}) > 10',
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
                      'id': '123',
                      'match_by': 'flavor_id,image_id',
                      'name': '90% CPU',
@@ -696,6 +727,38 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                                                     limit=1)
         self.assertEqual(alarmDef1, [])
 
+    def test_should_find_and_sort(self):
+        expected = [{'actions_enabled': False,
+                     'alarm_actions': '29387234,77778687',
+                     'description': None,
+                     'expression': 'AVG(hpcs.compute{flavor_id=777, '
+                     'image_id=888, metric_name=cpu, device=1},deterministic) > 10',
+                     'id': '123',
+                     'match_by': 'flavor_id,image_id',
+                     'name': '90% CPU',
+                     'ok_actions': None,
+                     'severity': 'LOW',
+                     'undetermined_actions': None},
+                    {'actions_enabled': False,
+                     'alarm_actions': '29387234,77778687',
+                     'description': None,
+                     'expression': 'AVG(hpcs.compute{flavor_id=777, '
+                     'image_id=888, metric_name=mem}) > 20 and '
+                     'AVG(hpcs.compute) < 100',
+                     'id': '234',
+                     'match_by': 'flavor_id,image_id',
+                     'name': '50% CPU',
+                     'ok_actions': None,
+                     'severity': 'LOW',
+                     'undetermined_actions': None}]
+
+        alarmDef1 = self.repo.get_alarm_definitions(tenant_id='bob',
+                                                    sort_by=['id'])
+        self.assertEqual(expected, alarmDef1)
+        alarmDef2 = self.repo.get_alarm_definitions(tenant_id='bob',
+                                                    sort_by=['name'])
+        self.assertEqual(expected[::-1], alarmDef2)
+
     def test_should_delete_by_id(self):
         self.repo.delete_alarm_definition('bob', '123')
         from monasca_api.common.repositories import exceptions
@@ -721,6 +784,10 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
                                                     limit=1)
         self.assertEqual(alarmDef1, expected)
 
+    def test_try_delete_alarm_that_does_not_exist(self):
+        response = self.repo.delete_alarm_definition('goku', '123')
+        self.assertEqual(False, response)
+
     def test_should_patch_name(self):
         self.run_patch_test(name=u'90% CPU New')
 
@@ -753,6 +820,10 @@ class TestAlarmDefinitionRepoDB(base.BaseTestCase):
     def test_should_patch_expression_threshold_change(self):
         self.run_patch_test(expression=ALARM_DEF_123_FIELDS['expression'].replace(' 10', ' 20'))
 
+    def test_should_patch_expression_deterministic_change(self):
+        self.run_patch_test(expression=ALARM_DEF_123_FIELDS['expression'].replace(',deterministic',
+                                                                                  ''))
+
     def test_should_patch_expression_function_change(self):
         self.run_patch_test(expression=ALARM_DEF_123_FIELDS['expression'].replace('AVG', 'MAX'))
 
