@@ -21,7 +21,7 @@ from datetime import datetime
 
 import cassandra
 from cassandra.auth import PlainTextAuthProvider
-from mock import patch
+from unittest.mock import patch
 
 from oslo_config import cfg
 from oslo_utils import timeutils
@@ -48,13 +48,15 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
                         ["2015-03-14T09:26:53.59Z", 2, None],
                         ["2015-03-14T09:26:53.591Z", 2.5, ''],
                         ["2015-03-14T09:26:53.6Z", 4.0, '{}'],
-                        ["2015-03-14T09:26:54Z", 4, '{"key": "value"}']
+                        ["2015-03-14T09:26:54Z", 4, '{"key": "value"}'],
+                        ["2015-03-14T09:26:53.1234567Z", 1, '{}']
                     ]
                 }
             ]
         }
 
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
         result = repo.measurement_list(
             "tenant_id",
             "region",
@@ -79,7 +81,8 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
             [["2015-03-14T09:26:53.590Z", 2, {}],
              ["2015-03-14T09:26:53.591Z", 2.5, {}],
              ["2015-03-14T09:26:53.600Z", 4.0, {}],
-             ["2015-03-14T09:26:54.000Z", 4, {"key": "value"}]],
+             ["2015-03-14T09:26:54.000Z", 4, {"key": "value"}],
+             ["2015-03-14T09:26:53.123Z", 1, {}]],
             measurements
         )
 
@@ -92,23 +95,14 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
                 u'values': [[
                     u'disk.space_used_perc,_region=region,_tenant_id='
                     u'0b5e7d8c43f74430add94fba09ffd66e,device=rootfs,'
-                    'hostname=host0,hosttype=native,mount_point=/',
-                    u'region',
-                    u'0b5e7d8c43f74430add94fba09ffd66e',
-                    u'rootfs',
-                    u'host0',
-                    u'native',
-                    u'',
-                    u'/'
+                    'hostname=host0,hosttype=native,mount_point=/'
                 ]],
-                u'name': u'disk.space_used_perc',
-                u'columns': [u'_key', u'_region', u'_tenant_id', u'device',
-                             u'hostname', u'hosttype', u'extra', u'mount_point']
+                u'columns':[u'key']
             }]
         }
 
         repo = influxdb_repo.MetricsRepository()
-
+        repo._version = 'from_0.11.0'
         result = repo.list_metrics(
             "0b5e7d8c43f74430add94fba09ffd66e",
             "region",
@@ -160,6 +154,7 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
         group_by = None
 
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
         stats_list = repo.metrics_statistics(tenant_id, region, name,
                                              dimensions, start_timestamp,
                                              end_timestamp, statistics,
@@ -167,7 +162,7 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
                                              merge_metrics_flag, group_by)
         expected_result = [{
             u'columns': [u'timestamp', u'avg'],
-            u'dimensions': {u'mean': 0.047, u'time': u'1970-01-01T00:00:00Z'},
+            u'dimensions': {},
             u'id': '0',
             u'name': u'cpu.utilization',
             u'statistics': [[u'1970-01-01T00:00:00Z', 0.047]]}]
@@ -179,6 +174,7 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
         expected_clause = ' group by hostname,service,time(300s) fill(none)'
 
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
         clause = repo._build_group_by_clause(group_by, period)
         self.assertEqual(clause, expected_clause)
 
@@ -187,58 +183,91 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
         expected_clause = ' group by hostname,service'
 
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
         clause = repo._build_group_by_clause(group_by)
         self.assertEqual(clause, expected_clause)
 
     @patch("monasca_api.common.repositories.influxdb."
            "metrics_repository.client.InfluxDBClient")
-    def test_list_dimension_values(self, influxdb_client_mock):
+    def test_list_dimension_values(self, influxdb_client_mock, timestamp=False):
         mock_client = influxdb_client_mock.return_value
-        mock_client.query.return_value.raw = {
-            u'series': [
-                {
-                    u'values': [[u'custom_host']],
-                    u'name': u'custom_metric',
-                    u'columns': [u'hostname']
-                }]
-        }
 
+        tenant_id = u'38dc2a2549f94d2e9a4fa1cc45a4970c'
+        region = u'useast'
+        metric = u'custom_metric'
+        column = u'hostname'
+        hostname = u'custom_host'
+        start_timestamp = 1571917171275
+        end_timestamp = 1572917171275
+        mock_client.query.return_value.raw = {
+            u'series': [{
+                u'values': [[column, hostname]],
+                u'name': metric,
+                u'columns': [u'key', u'value']
+            }]
+        }
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
         mock_client.query.reset_mock()
 
-        result = repo.list_dimension_values(
-            "38dc2a2549f94d2e9a4fa1cc45a4970c",
-            "useast",
-            "custom_metric",
-            "hostname")
+        db_per_tenant = repo.conf.influxdb.db_per_tenant
+        database = repo.conf.influxdb.database_name
+        database += "_%s" % tenant_id if db_per_tenant else ""
 
-        self.assertEqual(result, [{u'dimension_value': u'custom_host'}])
+        result = (repo.list_dimension_values(tenant_id, region, metric, column,
+                                             start_timestamp, end_timestamp)
+                  if timestamp else
+                  repo.list_dimension_values(tenant_id, region, metric, column))
 
-        mock_client.query.assert_called_once_with(
-            'show tag values from "custom_metric" with key = "hostname"'
-            ' where _tenant_id = \'{tenant}\''
-            '  and _region = \'{region}\' '.format(tenant=b'38dc2a2549f94d2e9a4fa1cc45a4970c',
-                                                   region=b'useast'))
+        self.assertEqual(result, [{u'dimension_value': hostname}])
+
+        query = ('show tag values from "{metric}"'
+                 ' with key = "{column}"'
+                 ' where _region = \'{region}\''
+                 .format(region=region, metric=metric, column=column))
+        query += ('' if db_per_tenant else ' and _tenant_id = \'{tenant_id}\''
+                  .format(tenant_id=tenant_id))
+        query += (' and time >= {start_timestamp}000000u'
+                  ' and time < {end_timestamp}000000u'
+                  .format(start_timestamp=start_timestamp,
+                          end_timestamp=end_timestamp)
+                  if timestamp else '')
+        mock_client.query.assert_called_once_with(query, database=database)
+
+    def test_list_dimension_values_with_timestamp(self):
+        self.test_list_dimension_values(timestamp=True)
 
     @patch("monasca_api.common.repositories.influxdb."
            "metrics_repository.client.InfluxDBClient")
-    def test_list_dimension_names(self, influxdb_client_mock):
+    def test_list_dimension_names(self, influxdb_client_mock, timestamp=False):
         mock_client = influxdb_client_mock.return_value
+
+        tenant_id = u'38dc2a2549f94d2e9a4fa1cc45a4970c'
+        region = u'useast'
+        metric = u'custom_metric'
+        start_timestamp = 1571917171275
+        end_timestamp = 1572917171275
         mock_client.query.return_value.raw = {
             u'series': [{
                 u'values': [[u'_region'], [u'_tenant_id'], [u'hostname'],
                             [u'service']],
-                u'name': u'custom_metric',
+                u'name': metric,
                 u'columns': [u'tagKey']
             }]
         }
 
         repo = influxdb_repo.MetricsRepository()
+        repo._version = 'from_0.11.0'
+        mock_client.query.reset_mock()
 
-        result = repo.list_dimension_names(
-            "38dc2a2549f94d2e9a4fa1cc45a4970c",
-            "useast",
-            "custom_metric")
+        db_per_tenant = repo.conf.influxdb.db_per_tenant
+        database = repo.conf.influxdb.database_name
+        database += "_%s" % tenant_id if db_per_tenant else ""
+
+        result = (repo.list_dimension_names(tenant_id, region, metric,
+                                            start_timestamp, end_timestamp)
+                  if timestamp else
+                  repo.list_dimension_names(tenant_id, region, metric))
 
         self.assertEqual(result,
                          [
@@ -246,6 +275,22 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
                              {u'dimension_name': u'service'}
                          ])
 
+        query = ('show tag keys from "{metric}"'
+                 ' where _region = \'{region}\''
+                 .format(region=region, metric=metric))
+        query += ('' if db_per_tenant else ' and _tenant_id = \'{tenant_id}\''
+                  .format(tenant_id=tenant_id))
+        query += (' and time >= {start_timestamp}000000u'
+                  ' and time < {end_timestamp}000000u'
+                  .format(start_timestamp=start_timestamp,
+                          end_timestamp=end_timestamp)
+                  if timestamp else '')
+
+        mock_client.query.assert_called_once_with(query, database=database)
+
+    def test_list_dimension_names_with_timestamp(self):
+        self.test_list_dimension_names(timestamp=True)
+
     @patch("monasca_api.common.repositories.influxdb."
            "metrics_repository.requests.head")
     def test_check_status(self, head_mock):
